@@ -306,7 +306,7 @@ class Keyring():
         if homedir is not None:
             self.context.set_option('homedir', homedir)
         else:
-            homedir = os.environ['HOME'] + '/.gnupg'
+            homedir = os.path.join(os.path.expanduser("~"), '.gnupg')
             if 'GNUPGHOME' in os.environ:
                 homedir = os.environ['GNUPGHOME']
         self.homedir = homedir
@@ -836,7 +836,7 @@ class OpenPGPkey():
 
 
     def __repr__(self):
-        s = '<OpenPGPKey(%s UIDs:%d)>'
+        s = '<OpenPGPkey(%s UIDs:%d)>'
         s %= (self.fpr,  len(self.uidslist))
         
         return s
@@ -858,6 +858,25 @@ class OpenPGPkey():
             if i == 4: s += ' '
         return s
 
+    def __eq__(self, other):
+        """
+        Two keys are equal if their fingerprint matches. If either don't
+        have a fingerprint, we can't say for sure that they're equal
+        """
+        if isinstance(other, self.__class__):
+            return (self.fpr and
+                    self.fpr and other.fpr
+                    and self.fpr == other.fpr)
+        else:
+            return NotImplemented
+
+    def __neq__(self, other):
+        if isinstance(other, self.__class__):
+            return not self.__eq__(other)
+        else:
+            return NotImplemented
+
+
 class OpenPGPuid():
     def __init__(self, uid, trust, creation = 0, expire = None, uidhash = ''):
         self.uid = uid
