@@ -559,7 +559,15 @@ ordering.
         assert(keys is not None)  # nosec
         self.log(_('found %d keys matching your request') % len(keys))
 
+        secret_keys = self.keyring.get_keys(self.options.user, True, False)
+
         for key in keys:
+            # Make sure the user isn't signing their own key
+            for secret_key in secret_keys.values():
+                if keys[key] == secret_key:
+                    self.warn(_('That is your own key, so it is already certified'))
+                    return False
+
             alluids = self.yes_no(_("""\
 Signing the following key
 
